DB_PATH = "db.json"

ICONS = [
    {"icon": "○", "title": "Not started"},
    {"icon": "◐", "title": "In progress"},
    {"icon": "◎", "title": "Under review"},
    {"icon": "✓", "title": "Done"},
    {"icon": "✗", "title": "Canceled/Won't do"},
]
PROJECT_TITLE_ID = "project-title"
TASK_CONTAINER_ID = "task-container"
PROJECT_DESCRIPTION_ID = "project-description"
PROJECT_TASK_TYPE_ID = "task"
EXPORT_PROJECT_ID = "export-project"
EXPORT_PROJECT_RADIO_ID = "import_export_radio"
IMPORT_PROJECT_ID = "import-project"
PROJECT_TYPE_ID = "project-type"
PROJECTS_ID = "projects"
CREATE_PROJECTS_ID = "create_to_do_modal"
IMPORT_EXPORT_MODAL_ID = "import_export_modal"
FOOTER_ID = "footer"
TASK_HEADER_ID = "task-header"
TASKS_ID = "tasks"
PROJECT_OTHER_TYPE_ID = "other"
PROJECT_MODAL_CONTENT = "project-modal-content"

# Screens
CREATE_PROJECT_ID = "create-project-modal"
SELECT_PROJECT_MODAL_ID = "select-project"
